@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.94';
+$VERSION = '0.95';
 
 #----------------------------------------------------------------------------
 
@@ -122,6 +122,13 @@ sub new {
     my @TOCOPY = split("\n", $cfg->val('TOCOPY','LIST'));
     $self->tocopy(\@TOCOPY);
 
+    my %TOLINK;
+    for my $link ($cfg->Parameters('TOLINK')) {
+        my $file = $cfg->val('TOLINK',$link);
+        $TOLINK{$link} = $file;
+    }
+    $self->tolink(\%TOLINK);
+
     $self->mainstore( _defined_or( $hash{mainstore},  $cfg->val('MASTER','mainstore' ) ));
     $self->leadstore( _defined_or( $hash{leadstore},  $cfg->val('MASTER','leadstore' ) ));
     $self->monthstore(_defined_or( $hash{monthstore}, $cfg->val('MASTER','monthstore'), 'cpanstats-%s.json' ));
@@ -207,7 +214,7 @@ Returns the print form of a recorded OS name.
 __PACKAGE__->mk_accessors(
     qw( directory mainstore leadstore monthstore templates database address 
         builder missing mailrc logfile logclean copyright noreports tocopy 
-        osnames));
+        tolink osnames));
 
 sub make_pages {
     my $self = shift;
@@ -348,7 +355,7 @@ http://rt.cpan.org/Public/Dist/Display.html?Name=CPAN-Testers-WWW-Statistics
 =head1 SEE ALSO
 
 L<CPAN::Testers::Data::Generator>,
-L<CPAN::WWW::Testers>
+L<CPAN::Testers::WWW::Reports>
 
 F<http://www.cpantesters.org/>,
 F<http://stats.cpantesters.org/>,
@@ -361,7 +368,7 @@ F<http://wiki.cpantesters.org/>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2005-2011 Barbie for Miss Barbell Productions.
+  Copyright (C) 2005-2012 Barbie for Miss Barbell Productions.
 
   This module is free software; you can redistribute it and/or
   modify it under the same terms as Perl itself.
